@@ -50,7 +50,7 @@
 #include <cc++/socket.h>
 #endif
 
-#define	BAYONNE_RELEASE	1		// release check sequence
+#define	BAYONNE_RELEASE	2		// release check sequence
 #define	NO_TIMESLOT	0xffff
 #define	MAX_DTMF	32
 #define	MAX_LIST	256
@@ -389,7 +389,6 @@ public:
 		CALL_RINGING,
 		CALL_DISCONNECT,
 		CALL_CLEARED,
-		CALL_PROCEEDING,
 		RESTART_FAILED,
 		RELEASE_FAILED,
 
@@ -474,14 +473,6 @@ public:
 		const char *list[MAX_LIBINPUT / 2];
 	}	libaudio_t;
 
-        typedef struct
-        {
-                const char *remote;
-                const char *userid;
-                const char *type;
-                const char *status;
-        }	regauth_t;
-
 	/**
 	 * The event data structure includes the event identifier and
 	 * any paramaters.  Additional information is attached both to
@@ -697,7 +688,7 @@ public:
 	 * @param timeslots to allocate.
 	 * @param pointer to server shell.
 	 */	
-	static void allocate(timeslot_t timeslots, ScriptCommand *pointer = NULL);
+	static void allocate(timeslot_t timeslots, ScriptCommand *server = NULL);
 
 	/**
 	 * Wait for live flag...
@@ -729,13 +720,13 @@ public:
 	 * @param service level or NULL to clear.
 	 * @return true if set.
 	 */
-	static bool service(const char *service);
+	static bool service(const char *svc);
 
 	/**
 	 * Returns a session pointer for a server timeslot.  Each
 	 * server timeslot can map to a single session object.
 	 *
-	 * @param timeslot number in server.
+	 * @param server timeslot number.
 	 * @return session object or NULL if timeslot empty/invalid.
 	 */
 	static BayonneSession *getSession(timeslot_t timeslot);
@@ -745,7 +736,7 @@ public:
 	 * be for a transaction id, a call id, or other unique identifiers
 	 * which can be mapped into a single timeslot.
 	 *
-	 * @param id session identifier string.
+	 * @param string session identifier.
 	 * @return session object or NULL if not found.
 	 */
 	static BayonneSession *getSid(const char *id);
@@ -754,7 +745,7 @@ public:
 	 * Returns a server timeslot number for a string identifier.
 	 *
 	 * @return timeslot number or invalid value.
-	 * @param id for a session.
+	 * @param string identifier for a session.
 	 * @see #getSid
 	 */
 	static timeslot_t toTimeslot(const char *id);
@@ -799,7 +790,7 @@ public:
 	 * @param dtmf digit as ascii
 	 * @return dtmf digit number.
 	 */
-	static int getDigit(char dtmf);
+	static int getDigit(char dig);
 
 	/**
 	 * Convert a dtmf digit number into it's ascii code.
@@ -811,12 +802,12 @@ public:
 
 	/**
 	 * A function to support pattern matching and templates for digit
-	 * strings.  This is used for digit \@xxx:... entries and the route
+	 * strings.  This is used for digit @xxx:... entries and the route
 	 * command.
 	 *
 	 * @param digits to use.
-	 * @param match digit pattern to match against.
-	 * @param partial accept match if true.
+	 * @param digit pattern to match against.
+	 * @param accept partial match.
 	 * @return true if digits match to pattern.
 	 */
 	static bool matchDigits(const char *digits, const char *match, bool partial = false);
@@ -832,14 +823,14 @@ public:
 	 * Release a script image in use.  If no active calls are using it
 	 * and it's no longer the top active image, purge from memory.
 	 *
-	 * @param image to compiled script from useImage.
+	 * @param script image from useImage.
 	 */
-	static void endImage(ScriptImage *image);
+	static void endImage(ScriptImage *img);
 
 	/**
 	 * Load a plugin module.
 	 *
-	 * @param path id of plugin.
+	 * @param id of plugin.
 	 * @return true if successful.
 	 */
 	static bool loadPlugin(const char *path);
@@ -847,7 +838,7 @@ public:
         /**
          * Load a monitoring/management module.
          *
-         * @param path id of plugin.
+         * @param id of plugin.
          * @return true if successful.
          */
         static bool loadMonitor(const char *path);  
@@ -855,7 +846,7 @@ public:
 	/**
 	 * Load a bgm/audio processing module for continues audio.
 	 *
-	 * @param path id of plugin.
+	 * @param id of plugin.
 	 * @return true if successful.
 	 */
 	static bool loadAudio(const char *path);
@@ -863,6 +854,56 @@ public:
 	static void errlog(const char *level, const char *fmt, ...); 
 };
 
+/**
+ * A core class to support audio feeds that can be used in continues
+ * audio processing, whether to feed background music, or other audio
+ * source overlays.
+ */
+class __EXPORT BayonneFeeder : public Audio, protected ThreadLock
+{
+protected:
+	static BayonneFeeder *first;
+	BayonneFeeder *next;
+
+	Sample buffer[MAX_AUDIOFEED];
+	const char *id;
+	unsigned pos, last;
+	unsigned count;
+	bool active;
+
+	void setEnding(void);
+
+	Linear putBuffer(unsigned size);
+
+public:
+	BayonneFeeder(const char *name);
+
+	/**
+	 * Get if encoding is native or not.
+	 *
+	 * @return true if native endian, else linear former...
+	 */
+	virtual bool isNative(void) = 0;
+
+	/**
+	 * Get last position to use.
+	 *
+	 * @return offset for getBuffer work...
+	 */
+	unsigned getPosition(void);
+
+	/**
+	 * Get a buffer for our offset.
+	 *
+	 * @param offset.
+	 * @param size we request.
+	 * @return first sample or NULL if inactive.
+	 */
+	Linear getBuffer(unsigned offset, unsigned size);
+
+	static BayonneFeeder *get(const char *id);
+};
+
 /**
  * A core class to support language translation services in Bayonne
  * phrasebook.
@@ -889,7 +930,7 @@ public:
 	 *
 	 * @param iso name of language/locale.
 	 */
-	BayonneTranslator(const char *iso);
+	BayonneTranslator(const char *id);
 
 	/**
 	 * Find a translator for a given name/location.
@@ -921,155 +962,134 @@ public:
 	 * @param iso module name to load.
 	 * @return true if successful.
 	 */
-	static BayonneTranslator *loadTranslator(const char *iso);
+	static BayonneTranslator *loadTranslator(const char *name);
 
 	/**
 	 * Translate a simple set of digits to spoken speech.
 	 *
-	 * @param session to save list of prompts.
-	 * @param count of current prompts used.
+	 * @param timeslot session to save list of prompts.
+	 * @param current count of prompts used.
 	 * @param string to be processed.
 	 * @return new count of prompts used.
 	 */
-	virtual unsigned digits(BayonneSession *sessiob, unsigned count, const char *string);
+	virtual unsigned digits(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Spell out the string as individual letters.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned spell(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned spell(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate an ordinal number (xxnth) to prompts.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned sayorder(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned sayorder(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a number to spoken speech.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned number(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned number(BayonneSession *s, unsigned count, const char *cp);
 
 	/**
 	 * Translate generic numbers to spoken speech.  This is the one
 	 * used by the &number rule.
 	 *
-	 * @param session to save list of prompts.
-	 * @param count of current prompts used.
+	 * @param timeslot session to save list of prompts.
+	 * @param current count of prompts used.
 	 * @param string to be processed.
 	 * @return new count of prompts used.
 	 */
-	virtual unsigned saynumber(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned saynumber(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a counting number (integer) to spoken speech.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saycount(BayonneSession *session, unsigned count, const char *string);
-
-        /**
-         * Translate a string for time into short hours.
-         *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
-         * @param string to be processed.
-         * @return new count of prompts used.
-         */
-        virtual unsigned sayhour(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned saycount(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a string for time into speech.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saytime(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned saytime(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a string with a date into the spoken weekday.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned weekday(BayonneSession *session, unsigned count, const char *string);
-
-	/*
-	 * Translate a string with a date into spoken date without year.
-         *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
-         * @param string to be processed.
-         * @return new count of prompts used.
-         */
-        virtual unsigned sayday(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned weekday(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a string with a date into a spoken date.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saydate(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned saydate(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a logical value and speak as yes/no.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saybool(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned saybool(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate and speak a phone number.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned phone(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned phone(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate and speak a phone extension.
          *
-         * @param session to save list of prompts.
-         * @param count of current prompts used.
+         * @param timeslot session to save list of prompts.
+         * @param current count of prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned extension(BayonneSession *session, unsigned count, const char *string);
+	virtual unsigned extension(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translation dispatch, processes script and invokes other methods.
          *
          * @return error message or NULL if okay
-	 * @param session to process a command from.
-	 * @param line of compiled script to process.
+	 * @param timeslot session to process a command from.
          */
 	virtual const char *speak(BayonneSession *session, Line *line = NULL);
 
@@ -1128,8 +1148,8 @@ public:
 	 * Convert a prompt identifier into a complete audio file pathname.
 	 *
 	 * @return pointer to fully qualified file path or NULL if invalid.
-	 * @param name of prompt requested.
-	 * @param write path required if true.
+	 * @param prompt requested.
+	 * @param true if request is for file write.
 	 */
         const char *getFilename(const char *name, bool write = false);
 
@@ -1143,18 +1163,18 @@ public:
 	 * Open a sequence of audio prompts for playback.	
 	 *
 	 * @param list of prompts to open.
-	 * @param mode for playback file processing of list.
+	 * @param playback mode for file processing of list.
 	 */
-	void play(const char **list, Mode mode = modeRead);
+	void play(const char **list, Mode m = modeRead);
 
 	/**
 	 * Open an audio prompt for recording.
 	 *
 	 * @param name of prompt to open.
-	 * @param mode whether to create or use pre-existing recording.
+	 * @param mode, whether to create or use pre-existing recording.
 	 * @param annotation to save in file if supported by format used.
 	 */
-	void record(const char *name, Mode mode = modeCreate, const char *annotation = NULL);
+	void record(const char *name, Mode m = modeCreate, const char *note = NULL);
 
 	/**
 	 * Check if a voice library is available.
@@ -1162,7 +1182,7 @@ public:
 	 * @return voice library id or NULL if invalid.
 	 * @param iso name of library to request.
 	 */
-	const char *getVoicelib(const char *iso);
+	const char *getVoicelib(const char *cp);
 
 	/**
 	 * Get audio codec used.
@@ -1287,16 +1307,18 @@ protected:
 	 */
 	virtual void stopDriver(void);
 
+	static const char *remapDriver(const char *id);
+
 public:
 	/**
 	 * Create a driver instance.
 	 *
-	 * @param pairs of default keyword entries for config.
-	 * @param key name of config key.
-	 * @param id string of driver.
+	 * @param default keyword entries for config.
+	 * @param name of config key.
+	 * @param driver id string.
 	 * @param whether front load or use all timeslots.
 	 */
-	BayonneDriver(Keydata::Define *pairs, const char *key, const char *id, bool pri);
+	BayonneDriver(Keydata::Define *pairs, const char *cfg, const char *id, bool pri);
 
 	/**
 	 * Destroy driver instance.
@@ -1339,24 +1361,24 @@ public:
 	 * Process driver protocol specific proxy registration requests.
 	 *
 	 * @return error message if invalid request, NULL if ok.
-	 * @param image of script being compiled.
+	 * @param script image being compiled.
 	 * @param line record of "register" command.
 	 */
-        virtual const char *registerScript(ScriptImage *image, Line *line);
+        virtual const char *registerScript(ScriptImage *img, Line *line);
 
 	/**
 	 * Process driver specific assign requests.
 	 *
 	 * @return error message if invalid request, NULL if ok.
-	 * @param image of script being compiled.
+	 * @param script image being compiled.
 	 * @param line record of "assign" command.
 	 */
-	virtual const char *assignScript(ScriptImage *image, Line *line);
+	virtual const char *assignScript(ScriptImage *img, Line *line);
 
 	/**
 	 * Find and return driver object from id name.
 	 *
-	 * @param id driver name.
+	 * @param driver name.
 	 * @return associated driver node.
 	 */
 	static BayonneDriver *get(const char *id);
@@ -1364,7 +1386,8 @@ public:
 	/**
 	 * Load a bayonne driver into memory.
 	 *
-	 * @param id driver name to load.
+	 * @param prefix path to load.
+	 * @param driver name to load.
 	 * @return NULL or pointer to loaded driver.
 	 */
 	static BayonneDriver *loadDriver(const char *id);
@@ -1389,8 +1412,8 @@ public:
 	/**
 	 * Get list of driver names into string array.
 	 *
-	 * @param items array to save in.
-	 * @param max count of elements available.
+	 * @param array to save in.
+	 * @param count of elements available.
 	 * @return number of drivers.
 	 */
 	static unsigned BayonneDriver::list(char **items, unsigned max);
@@ -1539,7 +1562,7 @@ public:
 	/**
 	 * Get the nth span object associated with this driver.
 	 *
-	 * @param id of nth span to return.
+	 * @param nth span to return.
 	 * @return span object or NULL if past limit/no spans.
 	 */
 	BayonneSpan *getSpan(unsigned id);
@@ -1548,7 +1571,7 @@ public:
 	 * Get the session associated with the nth timeslot for this
 	 * driver.
 	 *
-	 * @param id of nth timeslot of driver.
+	 * @param nth timeslot of driver.
 	 * @return session object.
 	 */
 	BayonneSession *getTimeslot(timeslot_t id);
@@ -1588,7 +1611,7 @@ public:
 	/**
 	 * Set driver logging.
 	 *
-	 * @param output stream to log driver.
+	 * @param stream to log driver.
 	 */
 	inline void setLogging(std::ostream *output)
 		{logevents = output;};
@@ -1605,13 +1628,13 @@ public:
 	 * Deterime if a network destination is reachable through this
 	 * driver, and convert dialing string into network reference.
 	 *
-	 * @param target network destination
-	 * @param dial string
+	 * @param network destination
+	 * @param dialing string
 	 * @param output buffer
 	 * @param size of output buffer
 	 * @return true if reachable
 	 */
-	virtual bool getDestination(const char *target, const char *dial, char *output, size_t size);
+	virtual bool getDestination(const char *target, const char *dial, char *buffer, size_t size);
 
 	/**
 	 * Get available timeslots.
@@ -1620,15 +1643,6 @@ public:
 	 */
 	inline unsigned getAvail(void)
 		{return avail;}
-
-        /**
-         * Fill registration data.
-         *
-         * @return number of records filled.
-         * @param data array to fill.
-         * @param number of entries available.
-         */
-        virtual unsigned getRegistration(regauth_t *data, unsigned count);
 };	
 
 /**
@@ -1661,12 +1675,12 @@ public:
 	 * @param driver associated with span.
 	 * @param timeslots this span covers.
 	 */
-	BayonneSpan(BayonneDriver *driver, timeslot_t timeslots);
+	BayonneSpan(BayonneDriver *d, timeslot_t count);
 
 	/**
 	 * Get a span by a global span id.
 	 *
-	 * @param id of span.
+	 * @param numeric span id.
 	 * @return span object associated with id.
 	 */
 	static BayonneSpan *get(unsigned id);
@@ -1674,7 +1688,7 @@ public:
 	/**
 	 * Get the session associated with the nth timeslot of the span.
 	 *
-	 * @param id of nth timeslot of span.
+	 * @param nth timeslot of span.
 	 * @return associated session object.
 	 */
 	BayonneSession *getTimeslot(timeslot_t id);
@@ -1684,7 +1698,7 @@ public:
 	 *
 	 * @param total span count.
 	 */
-	static void allocate(unsigned total = 0);
+	static void allocate(unsigned count = 0);
 
 	/**
 	 * Return total spans in use.
@@ -1798,7 +1812,7 @@ protected:
 	uint32 tseq;
 	volatile unsigned children;
 	bool offhook, dtmf, answered, starting, holding;
-	time_t audiotimer, starttime;
+	time_t exittimer, starttime;
 	interface_t iface;
 	bridge_t bridge;
 	calltype_t type;
@@ -1824,6 +1838,14 @@ protected:
 	 */
 	virtual void disableDTMF(void);
 
+	/**
+	 * Set continues audio feed if allowed.
+	 *
+	 * @param feed to set or NULL to clear.
+	 * @return true if successful.
+	 */
+	virtual bool setFeeder(BayonneFeeder *feeder);
+
 	/**
 	 * Check audio properties for file and channel audio processing
 	 * based on the driver specific capabilities of this channel
@@ -1871,7 +1893,6 @@ protected:
 	 */
 	void check(void);
 
-	void renameRecord(void);
 	bool stateInitial(Event *event);
 	bool stateFinal(Event *event);
 	bool stateIdle(Event *event);
@@ -1922,9 +1943,9 @@ protected:
 	 *
 	 * @param string to write.
 	 */
-	void libWrite(const char *string);
+	void libWrite(const char *str);
 
-	void libClose(const char *string);
+	void libClose(const char *str);
 
 	bool isLibexec(const char *tsid);
 
@@ -1936,10 +1957,10 @@ public:
 	/**
 	 * Process interpreter session symbols.
 	 *
-	 * @param option symbol being requested.
+	 * @param symbol being requested.
 	 * @return NULL if not external, else value.
 	 */
-	const char *getExternal(const char *option);
+	const char *getExternal(const char *opt);
 
 	/**
 	 * Get event sequence id
@@ -1961,7 +1982,7 @@ protected:
 	/**
 	 * Return ccengine symbol page map.  Gives access to globals.
 	 *
-	 * @param id table of symbols.
+	 * @param table symbol id.
 	 * @return table map to use.
 	 */
 	ScriptSymbols *getSymbols(const char *id);
@@ -2075,11 +2096,11 @@ public:
 	/**
 	 * Create a new session
 	 *
-	 * @param driver to bind.
-	 * @param timeslot to bind.
-	 * @param span to bind, or NULL if no span associated.
+	 * @param bind to driver.
+	 * @param bind to timeslot.
+	 * @param bind to span, or NULL if no span associated.
 	 */
-	BayonneSession(BayonneDriver *driver, timeslot_t timeslot, BayonneSpan *span = NULL);
+	BayonneSession(BayonneDriver *d, timeslot_t timeslot, BayonneSpan *span = NULL);
 
 	/**
 	 * Destroy a session.
@@ -2116,7 +2137,7 @@ public:
 	 * Return time remaining until timer expires.  Commonly used for
 	 * msgport scheduling.
 	 *
-	 * @return time remaining in milliseconds.
+	 * @param time remaining in milliseconds.
 	 */
 	virtual timeout_t getRemaining(void) = 0;
 
@@ -2124,7 +2145,7 @@ public:
 	 * Start a timer on the session.  Used extensivily in state
 	 * handler code.
 	 *
-	 * @param timer to start for specified milliseconds.
+	 * @param start timer for specified milliseconds.
 	 */
 	virtual void startTimer(timeout_t timer) = 0;
 
@@ -2137,7 +2158,7 @@ public:
 	/**
 	 * Set the port hook state.  Mostly for analog devices.
 	 *
-	 * @param state true to set offhook, false onhook.
+	 * @param true to set offhook, false onhook.
 	 */
 	virtual void setOffhook(bool state);
 
@@ -2149,7 +2170,7 @@ public:
 	/**
 	 * Disconnect notify peer...
 	 *
-	 * @param reason event id to pass
+	 * @param event id to pass
 	 */
 	void part(event_t reason);
 
@@ -2200,7 +2221,7 @@ public:
 	 * Check script keywords for audio processing.
 	 *
 	 * @return NULL if ok, else error message.
-	 * @param live true if for live, else for file processing.
+	 * @param true if for live, else for file processing.
 	 */
 	const char *getAudio(bool live = true);
 
@@ -2278,8 +2299,8 @@ public:
 	 * @param signal to send to script engine.
 	 * @return true if signal claimed.
 	 */
-	inline bool signalScript(signal_t signal)
-		{return ScriptInterp::signal(signal);};
+	inline bool signalScript(signal_t sig)
+		{return ScriptInterp::signal(sig);};
 
 	/**
 	 * Post a peer audio frame into the driver.  The frame is assumed
@@ -2288,7 +2309,7 @@ public:
 	 * format.
 	 *
 	 * @return true if peer frame was posted.
-	 * @param encoded audio frame to peer.
+	 * @param audio frame to peer.
 	 */
 	virtual bool peerAudio(Audio::Encoded encoded);
 
@@ -2299,7 +2320,7 @@ public:
 	 *
 	 * @return true if set.
 	 * @param encoding format requested.
-	 * @param framing timer to use.
+	 * @param frame timing to use.
 	 */
 	virtual bool setPeering(Audio::Encoding encoding, timeout_t framing);
 
@@ -2338,7 +2359,7 @@ public:
 	 * @return true if throw caught.
 	 * @param event message.
 	 */
-	bool digitEvent(const char *event);
+	bool digitEvent(const char *evt);
 
 	inline bool stringEvent(const char *evt)
 		{return scriptEvent(evt);}
