@@ -80,6 +80,15 @@ public:
 	 */
 	Libexec();
 
+	/**
+	 * Post a symbol asychrononous event to server.  This sets the
+	 * symbol value, and also generates a @posted:symname event.
+	 *
+	 * @param id of symbol to post.
+	 * @param value of symbol.
+	 */
+	void postSym(const char *id, const char *value);
+
 	/**
 	 * Get a header record item.
 	 *
@@ -100,9 +109,9 @@ public:
 	 * Get a fully qualified and resolved pathname.
 	 *
 	 * @return pointer to buffer or NULL if invalid.
-	 * @param filename path to evaluate.
+	 * @param file path to evaluate.
 	 * @param buffer to save into.
-	 * @param size of buffer.
+	 * @param max size of buffer.
 	 */
 	const char *getPath(const char *filename, char *buffer, unsigned size);
 
@@ -110,7 +119,7 @@ public:
          * Get and verify partial pathname for file oriented libexec commands.
          *
          * @return pointer to buffer or NULL if invalid.
-         * @param filename path to evaluate.
+         * @param file path to evaluate.
          */
         const char *getFile(const char *filename);
 
@@ -119,16 +128,16 @@ public:
 	 *
 	 * @param voice to set or NULL for default.
 	 */
-	inline void setVoice(const char *voice)
-		{voice = voice;};
+	inline void setVoice(const char *v)
+		{voice = v;};
 
 	/**
 	 * Set the effective audio level for tones...
 	 *
 	 * @param level to set.
 	 */
-	inline void setLevel(Audio::Level level)
-		{level = level;};
+	inline void setLevel(Audio::Level l)
+		{level = l;};
 
 	/**
 	 * Hangup running session...
@@ -275,15 +284,6 @@ public:
 	result_t addSym(const char *id, const char *value);
 	result_t setSym(const char *id, const char *value);
 	result_t getSym(const char *id, char *buf, unsigned size);
-
-        /**
-         * Post a symbol asychrononous event to server.  This sets the
-         * symbol value, and also generates a @posted:symname event.
-         *
-         * @param id of symbol to post.
-         * @param value of symbol.
-         */  
-	void postSym(const char *id, const char *value);
 };	 
 
 class __EXPORT BayonneTSession : public BayonneSession
