@@ -42,6 +42,7 @@ ScriptInterp(), audio()
 	evseq = 0;
 	tseq = 0;
 	offhook = dtmf = answered = holding = false;
+	exittimer = 0;
 	starttime = 0;
 	type = NONE;
 	seizure = CHILD_RUNNING;
@@ -103,8 +104,14 @@ void BayonneSession::initialize(void)
 	setSid();
 }
 
+bool BayonneSession::setFeeder(BayonneFeeder *feeder)
+{
+	return false;
+}
+
 void BayonneSession::detach(void)
 {
+	exittimer = 0;
 	answered = false;
 	digit_count = ring_count = 0;
 
@@ -290,6 +297,7 @@ void BayonneSession::setSid(void)
 const char *BayonneSession::getExternal(const char *id)
 {
 	time_t now;
+	Line *line;
 
 	const char *p = strchr(id, '.');
 	char *tmp;
@@ -302,19 +310,6 @@ const char *BayonneSession::getExternal(const char *id)
 		id += 8;
 		if(!stricmp(id, "gid") || !stricmp(id, "id") || !stricmp(id, "sid"))
 			return var_sid;
-		else if(!stricmp(id, "index"))
-		{
-			tmp = getTemp();
-			snprintf(tmp, 10, "%d", timeslot);
-			return tmp;
-		}
-		else if(!stricmp(id, "timestamp"))
-		{
-			tmp = getTemp();
-			time(&now);
-			snprintf(tmp, 16, "%ld", now);
-			return tmp;
-		}
 		else if(!stricmp(id, "uid"))
 		{
 			tmp = getTemp();
@@ -329,6 +324,20 @@ const char *BayonneSession::getExternal(const char *id)
 			snprintf(tmp, 24, "%08x-%04x.%s", now, timeslot, audio.libext);
 			return tmp;
 		}		
+		else if(!stricmp(id, "dtmf"))
+		{
+			line = getLine();
+			if(!line)
+				return "exit";
+
+			if(state.menu)
+				return "menu";
+			if(!(line->mask & 0x08))
+				return "masked";
+			if(!(frame[stack].mask & 0x08))
+				return "off";
+			return "on";
+		}
 		else if(!stricmp(id, "libext"))
 			return audio.libext;	
 		else if(!stricmp(id, "line"))
@@ -345,8 +354,6 @@ const char *BayonneSession::getExternal(const char *id)
 			return var_callid;
 		else if(!stricmp(id, "timeslot"))
 			return var_timeslot;
-		else if(!stricmp(id, "servertype"))
-			return "sa";
 		else if(!stricmp(id, "deviceid"))
 			return logname;
 		else if(!stricmp(id, "voice"))
@@ -1022,31 +1029,25 @@ void BayonneSession::check(void)
 	Line *line = getLine();
 	Name *scr = getName();
 
-        if(state.menu)
-        {
-                dtmf = enableDTMF();
-                return;
-        }
+	if(state.menu)
+	{
+		dtmf = enableDTMF();
+		return;
+	}
 
-        if(!image || !line)
-        {
-                dtmf = false;
-                return;
-        }
+	if(!image || !line)
+	{
+		dtmf = false;
+		return;
+	}
 
-        if(server->isInput(line))
-        {
-                dtmf = enableDTMF();
-                return;
-        }
+	if((frame[stack].mask & 0x8) || server->isInput(line))
+	{
+		dtmf = enableDTMF();
+		return;
+	}
 
-        if((frame[stack].mask & 0x8) && (line->mask & 0x08))
-        {
-                dtmf = enableDTMF();
-                return;
-        }
-
-        disableDTMF();
+	disableDTMF();
 }
 
 bool BayonneSession::digitEvent(const char *evt)
@@ -1199,6 +1200,12 @@ const char *BayonneSession::getExitKeyword(const char *def)
 	if(!stricmp(cp, "any"))
 		return "0123456789*#";
 
+	if(!stricmp(cp, "pound"))
+		return "#";
+
+	if(!stricmp(cp, "star"))
+		return "*";
+
 	return cp;
 }	
 
@@ -1218,6 +1225,12 @@ const char *BayonneSession::getMenuKeyword(const char *def)
 	if(!stricmp(cp, "any"))
                 return "0123456789*#";
 
+	if(!stricmp(cp, "pound"))
+		return "#";
+
+	if(!stricmp(cp, "star"))
+		return "*";
+
         return cp;
 }
 
