@@ -456,7 +456,9 @@ bool BayonneSession::stateCollect(Event *event)
 		count = getInputCount(state.input.exit, state.input.count);
 		if(!count)
 		{
-			if(digit_count)
+			if(digit_count && digit_count == state.input.count - 1)
+				state.timeout = state.input.lastdigit;
+			else if(digit_count)
 				state.timeout = state.input.interdigit;
 
 			startTimer(state.timeout);
@@ -482,7 +484,6 @@ input:
                         }
                         while(size < MAX_DTMF && copy < count)
                                 data[size++] = dtmf_digits[copy++];
-
 			data[size] = 0;
                 }
                 else
@@ -539,7 +540,7 @@ bool BayonneSession::stateInput(Event *event)
 		}
 	case ENTER_STATE:
 		stopTimer();
-		if(state.input.exit)
+		if(state.input.exit && *state.input.exit)
 		{
 			last = state.input.count;
 			count = getInputCount(state.input.exit, state.input.count + 1);
@@ -552,8 +553,8 @@ bool BayonneSession::stateInput(Event *event)
 
 		if(!count)
 		{
-                        if(digit_count && digit_count == last)
-                                state.timeout = state.input.lastdigit; 
+			if(digit_count && digit_count == last)
+				state.timeout = state.input.lastdigit;
 			else if(digit_count)
 				state.timeout = state.input.interdigit;
 
@@ -607,7 +608,6 @@ input:
 			data[count] = 0;
 		}
 
-
 		dtmf_digits[0] = 0;
 		digit_count = 0;
 		data[size--] = 0;
@@ -665,9 +665,7 @@ bool BayonneSession::stateRead(Event *event)
 
 		if(!count)
 		{
-                        if(digit_count && digit_count == state.input.count - 1)
-                                state.timeout = state.input.lastdigit;   
-			else if(digit_count)
+			if(digit_count)
 				state.timeout = state.input.interdigit;
 
 			startTimer(state.timeout);
@@ -865,9 +863,63 @@ bool BayonneSession::stateTone(Event *event)
 
 bool BayonneSession::stateDTMF(Event *event)
 {
-	return stateTone(event);
+	Event ev;
+
+	if(event->id != TIMER_EXPIRED)
+		if(enterDTMF(event))
+			return true;
+
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		state.tone.flashing = false;
+		if(!state.tone.syncdigit || !*state.tone.syncdigit)
+			return true;
+		if(!state.tone.synctimer || state.tone.synctimer == TIMEOUT_INF)
+			return true;
+	case TIMER_EXPIRED:
+		if(!*state.tone.syncdigit)
+			return true;
+		memset(&ev, 0, sizeof(ev));
+		ev.id = DTMF_KEYSYNC;
+		ev.dtmf.duration = state.tone.synctimer / 2;
+		ev.dtmf.digit = *state.tone.syncdigit - '0';
+		enterDTMF(&ev);				
+		++state.tone.syncdigit;
+		startTimer(state.tone.synctimer);
+		return true;
+	case AUDIO_IDLE:
+		if(state.tone.exiting)
+		{
+			setState(STATE_HANGUP);
+			return true;
+		}
+		if(setLibreset(RESULT_COMPLETE))
+			return true;
+
+		advance();
+		setRunning();
+		return true;
+	case LINE_HANGUP:
+		if(state.tone.flashing)
+			return false;
+		break;
+	case START_FLASH:
+		state.tone.flashing = true;
+		setOffhook(false);
+		break;
+	case STOP_FLASH:
+		setOffhook(true);
+		state.tone.flashing = false;
+		break;
+	case TONE_START:
+		return false;
+	}
+
+	return enterCommon(event);
 }
 
+
 bool BayonneSession::stateConnect(Event *event)
 {
 	Event cancel;
@@ -1007,57 +1059,10 @@ exitkey:
         return enterCommon(event);
 }
 
-void BayonneSession::renameRecord(void)
-{
-	const char *path = audio.getFilename(state.audio.list[0], true);
-
-	if(!path || !state.audio.list[1])
-		return;
-
-	rename(path, state.audio.list[1]);
-	state.audio.list[1] = NULL;
-}
-
 bool BayonneSession::stateRecord(Event *event)
 {
 	char evtmsg[65];
 	char key;
-	time_t now;
-	const char *path;
-	char *buffer = (char *)&state.audio.list[2];
-
-        switch(event->id)
-        {
-        case ENTER_STATE:
-                time(&audiotimer);
-		if(!state.audio.list[1])
-			break;
-		path = audio.getFilename(state.audio.list[1], true);
-		if(path)
-		{
-			setString(buffer, 256, path);
-			state.audio.list[1] = buffer;
-		}
-		else
-			state.audio.list[1] = NULL;	
-                break;
-        case STOP_DISCONNECT:
-        case STOP_SCRIPT:
-        case CALL_DISCONNECT:
-        case CALL_FAILURE:
-                time(&now);
-                if(now - audiotimer > 3 || state.audio.total < 30000)
-		{
-			renameRecord();
-                        break;
-		}
-		path = audio.getFilename(state.audio.list[0], true);
-                remove(path);
-		state.audio.list[1] = 0;
-		break;
-	case AUDIO_IDLE:
-		renameRecord();
-        }
 
         if(enterRecord(event))
                 return true;
@@ -1100,11 +1105,9 @@ bool BayonneSession::stateRecord(Event *event)
 		key = getChar(event->dtmf.digit);
 		if(state.audio.exit && strchr(state.audio.exit, key))
 		{
-			renameRecord();
 			snprintf(evtmsg, sizeof(evtmsg), "exitkey:%c", key);
 			if(scriptEvent(evtmsg))
 			{
-				renameRecord();
 				setRunning();
 				return true;
 			}
@@ -1127,7 +1130,6 @@ exitkey:
 			*dtmf_digits = key;
 			dtmf_digits[1] = 0;
 			digit_count = 1;
-			renameRecord();
 			advance();
 			setRunning();
 			return true;
@@ -1281,21 +1283,6 @@ bool BayonneSession::stateXfer(Event *event)
 
 	switch(event->id)
 	{
-        case DIAL_BUSY:
-                if(!scriptEvent("transfer:busy"))
-                        error("transfer-busy");
-                setRunning();
-                return true;
-        case DIAL_INVALID:
-                if(!scriptEvent("transfer:invalid"))
-                        error("transfer-invalid");
-                setRunning();
-                return true;
-        case DIAL_FAILED:
-                if(!scriptEvent("transfer:failed"))
-                        error("transfer-failed");
-                setRunning();
-                return true;
 	case ENTER_STATE:
 		event->errmsg = "feature-unsupported";
 	case ERROR_STATE:
@@ -1427,7 +1414,6 @@ bool BayonneSession::stateIdle(Event *event)
 	case LINE_WINK:
 	case LINE_DISCONNECT:
 	case STOP_DISCONNECT:
-	case CALL_DISCONNECT:
 	case CANCEL_CHILD:
 	case STOP_SCRIPT:
 	case EXIT_THREAD:
@@ -1620,7 +1606,6 @@ noanswer:
 	case TIMER_EXPIRED:
 		if(state.join.dial)
 			goto noanswer;
-	case CALL_FAILURE:
 	case DIAL_FAILED:
 failed:
 		seizure = CHILD_FAILED;
@@ -1688,7 +1673,7 @@ bool BayonneSession::stateRunning(Event *event)
 			thread = NULL;
 			startTimer(reset_timer);
 			return true;
-		}
+		}		
 	case TIMER_EXPIRED:
 		clrAudio();
 		step();
@@ -1802,6 +1787,9 @@ bool BayonneSession::filterPosting(Event *event)
 	case DTMF_KEYDOWN:
 		if(!dtmf || !dtmf_digits)
 			return false;
+		line = getLine();
+		if(line && !(line->mask & 0x08))
+			return false;
 		digit_count = strlen(dtmf_digits);
 		return true;
 	case STOP_PARENT:
@@ -1901,13 +1889,13 @@ bool BayonneSession::enterCommon(Event *event)
 			return true;
 		}
 		return false;
-        case POST_LIBEXEC:
-                if(scriptEvent(event->name))
-                {
-                        setRunning();
-                        return true;
-                }
-                return false;  
+	case POST_LIBEXEC:
+		if(scriptEvent(event->name))
+		{
+			setRunning();
+			return true;
+		}
+		return false;
 	case PEER_WAITING:
 		if(scriptEvent("start:waiting"))
 		{
