@@ -22,6 +22,70 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkBind(Line *line, ScriptImage *img)
+{
+	char name[32];
+	ScriptCommand *cmd = img->getCommand();
+	Method handler;
+
+	const char *cp;
+	unsigned idx = 0;
+	if(getMember(line))
+		return "ifbind has no members";
+
+	cp = getOption(line, &idx);
+	if(!cp)
+		return "binding identifer missing";
+
+	if(!isalpha(*cp) && *cp != '{')
+		return "binding identifer must be a const identifier";
+
+	if(*cp == '{')
+		++cp;
+
+	snprintf(name, sizeof(name), "%sxml", cp);
+	cp = getOption(line, &idx);
+	if(!cp)
+		return "binding url missing";
+
+	if(getOption(line, &idx))
+		return "too many arguments for binding";
+
+	if(*cp == '{')
+		++cp;
+
+	if(strnicmp(cp, "http:/", 6) && strnicmp(cp, "file:/", 6))
+		return "binding target must be complete http or file url";
+
+	// strip command if no binding/method handler...
+
+	if(stricmp(name, keyserver.getLast("binding")))
+		return "";
+
+	handler = cmd->getHandler(name);
+	if(handler == NULL)
+		return "";
+
+	return NULL;
+}
+
+const char *Checks::chkBGM(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "bgm has no members";
+
+	if(hasKeywords(line))
+		return "bgm uses no keywords";
+
+	if(line->argc > 1)
+		return "bgm has only one argument";
+
+	if(!line->argc)
+		return "bgm feed argument is missing";
+
+	return NULL;
+}
+
 const char *Checks::chkConfig(Line *line, ScriptImage *img)
 {
 	Name *scr = img->getCurrent();
@@ -207,7 +271,7 @@ const char *Checks::chkList(Line *line, ScriptImage *img)
 	if(getMember(line))
 		return "list has no members";
 
-	if(!useKeywords(line, "=prefix=match=extension=after"))
+	if(!useKeywords(line, "=prefix=match=extension"))
 		return "invalid keyword for list";
 
 	cp = getOption(line, &idx);
@@ -540,8 +604,8 @@ const char *Checks::chkRecord(Line *line, ScriptImage *img)
 	if(!getOption(line, &idx))
 		return "requires one file argument";
 
-	if(getOption(line, &idx) && getOption(line, &idx))
-		return "uses only up to two file argument";
+	if(getOption(line, &idx))
+		return "uses only one file argument";
 
 	return NULL;
 }
@@ -580,8 +644,8 @@ const char *Checks::chkAppend(Line *line, ScriptImage *img)
 	if(!getOption(line, &idx))
 		return "requires one file argument";
 
-	if(getOption(line, &idx) && getOption(line, &idx))
-		return "uses up to two file argument";
+	if(getOption(line, &idx))
+		return "uses only one file argument";
 
 	return NULL;
 }
@@ -589,11 +653,12 @@ const char *Checks::chkAppend(Line *line, ScriptImage *img)
 const char *Checks::chkPathname(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
-	
+	const char *cp;
+		
 	if(!useKeywords(line, "=extension=voice=encoding=prefix"))
 		return "invalid keyword used";
 
-	if(!getOption(line, &idx))
+	if(NULL == (cp = getOption(line, &idx)))
 		return "requires at least one prompt argument";
 
 	return NULL;
@@ -604,7 +669,7 @@ const char *Checks::chkCollect(Line *line, ScriptImage *img)
 	unsigned idx = 0;
 	const char *cp;
 
-	if(!useKeywords(line, "=count=timeout=lastdigit=interdigit=ignore=exit=format"))
+	if(!useKeywords(line, "=count=timeout=interdigit=lastdigit=ignore=exit=format"))
 		return "invalid keyword for collect";
 
 	cp = getOption(line, &idx);
