@@ -92,6 +92,9 @@ static Keydata::Define paths[] = {
 #endif
 	{NULL, NULL}};
 
+static Keydata::Define protocols[] = {
+	{NULL, NULL}};
+
 static Keydata::Define server[] = {
 	{"user", "bayonne"},
 	{"group", "bayonne"},
@@ -101,7 +104,7 @@ static Keydata::Define server[] = {
 	{"state", "init"},
 	{"logging", "warn"},
 	{"monitoring", "tcp"},
-	{"binding", "default"},
+	{"binding", "ivrscript1"},
 	{NULL, NULL}};
 
 static Keydata::Define engine[] = {
@@ -112,17 +115,18 @@ static Keydata::Define engine[] = {
 	{"userid", ""},
 	{"secret", ""},
 	{"timeslots", "32"},
-	{"driver", "autodetect"},
 	{NULL, NULL}};
 
 #ifdef	WIN32
 Keydata keypaths(paths, "/bayonne/paths");
 Keydata keyserver(server, "/bayonne/server");
 Keydata keyengine(engine, "/bayonne/engine");
+Keydata keyprotocols(protocols, "/bayonne/protocols");
 #else
 Keydata keypaths(paths, "/bayonne/server/paths");
 Keydata keyserver(server, "/bayonne/server/server");
 Keydata keyengine(engine, "/bayonne/server/engine");
+Keydata keyprotocols(protocols, "/bayonne/server/protocols");
 #endif
 Keydata keyoptions;
 
@@ -131,7 +135,7 @@ void liveConfig(void)
 	char path[256];
 	char lang[32];
 	const char *env;
-	char *p, *sp, *tok;
+	char *p;
 	const char *cp;
 	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
 
@@ -214,34 +218,14 @@ void liveConfig(void)
 		keypaths.setValue("tmpfs", path);
 
 #endif
-        sp = (char *)keyserver.getLast("definitions");
-        if(sp && !stricmp(sp, "none"))
-                sp = NULL;
-
-        if(sp && !*sp)
-                sp = NULL;
-        if(sp)
-                cp = strtok_r(sp, " ,;:\t", &tok);
-        else
-                cp = NULL;
-
-        while(cp)
-        {
-                if(strrchr(cp, '.'))
-                        setString(path, sizeof(path), cp);
-                else
-                        snprintf(path, sizeof(path), "%s.def", cp);
-                runtime.setValue("definitions", path);
-                cp = strtok_r(NULL, " ,;:\t", &tok);
-        }
-
 	cp = keyoptions.getLast("prefix");
 #ifdef	WIN32
-	if(Bayonne::provision_test)
-		cp = NULL;
-#endif
+	if(cp && *cp && !Bayonne::provision_test)
+		chdir(cp);
+#else
 	if(cp && *cp)
 		chdir(cp);
+#endif
 
 	env = Process::getEnv("LANG");
 	if(env)
@@ -461,6 +445,7 @@ void loadConfig(void)
 		keypaths.load("~bayonne/paths");
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
+		keyprotocols.load("~bayonne/protocols");
 		runtime.loadPrefix("virtual", "~bayonne/virtual");
 	}
 
@@ -469,6 +454,7 @@ void loadConfig(void)
 		keypaths.load("/bayonne/provision/paths");
 		keyserver.load("/bayonne/provision/server");
 		keyengine.load("/bayonne/provision/engine");
+		keyprotocols.load("/bayonne/provision/protocols");
 		runtime.loadPrefix("virtual", "/bayonne/provision/virtual");
 	}
 
@@ -512,12 +498,6 @@ live:
 	keyoptions.setValue("prefix", keypaths.getLast("datafiles"));
 	keyserver.setValue("state", "live");
 
-#ifdef	SCRIPT_SERVER_PREFIX
-	Script::var_prefix = keypaths.getLast("datafiles");
-	Script::etc_prefix = keypaths.getLast("config");
-	Script::log_prefix = keypaths.getLast("logfiles");
-#endif
-
 	// only for live server...
 }
 
@@ -533,18 +513,6 @@ bool parseConfig(char **argv)
 	unsigned scrcount = 0;
 	unsigned minslots = 0;
 	bool live = true;
-	const char *cp;
-
-#ifndef	WIN32
-	cp = keyengine.getLast("driver");
-	if(cp && !stricmp(cp, "autodetect"))
-		cp = Process::getEnv("TIMESLOTS");
-	else if(cp && !stricmp(cp, "default"))
-		cp = Process::getEnv("TIMESLOTS");
-
-	if(cp && atoi(cp) > 0)
-		keyengine.setValue("timeslots", cp);
-#endif
 
 retry:
 	if(!*argv)
@@ -560,6 +528,7 @@ retry:
         if(!strnicmp("--", option, 2))
                 ++option;
 
+#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-driver=", 8))
 	{
 		keyengine.setValue("driver", option + 8);
@@ -567,6 +536,20 @@ retry:
 		goto retry;
 	} 
 
+	if(!strnicmp(option, "-trunking=", 10))
+        {
+                keyengine.setValue("trunking", option + 10);
+                ++argv;
+                goto retry;
+        }  
+
+        if(!strnicmp(option, "-protocol=", 10))     
+        {
+                keyengine.setValue("protocol", option + 10);
+                ++argv;
+                goto retry;
+        }   
+
         if(!strnicmp(option, "-bind=", 6))
         {
                 keyserver.setValue("binding", option + 6);    
@@ -574,7 +557,6 @@ retry:
                 goto retry;
         }  
 
-#ifdef	HAVE_TESTING
         if(!strnicmp(option, "-test=", 6))
         {
 		testConfig(argv0);
@@ -582,6 +564,13 @@ retry:
                 ++argv;
                 goto retry;
         }  
+
+	if(!stricmp(option, "-testing"))
+	{
+		++argv;
+		testConfig(argv0);
+		goto retry;
+	}
 	
 	if(!stricmp(option, "-test"))
 	{
@@ -623,8 +612,7 @@ retry:
                 ++argv;
                 goto retry;
         }
-#endif            
-
+            
 	if(!stricmp(option, "-check"))
 	{
 		keyserver.setValue("logging", "debug");
@@ -632,6 +620,7 @@ retry:
 		++argv;
 		goto retry;
 	}
+#endif
 
 	if(!strnicmp(option, "-vvv", 4))
 	{
@@ -665,6 +654,7 @@ retry:
 		goto retry;
 	}
 
+#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-voice=", 7))
 	{
 		keyserver.setValue("voice", option + 7);
@@ -687,7 +677,6 @@ retry:
                 goto retry;
         }
 
-#ifdef	HAVE_TESTING
         if(!stricmp(option, "-libexec"))
         {
                 ++argv;
@@ -736,7 +725,6 @@ retry:
                 keyserver.setValue("logging", *(argv++));
                 goto retry;
         }
-#endif
 
         if(!stricmp(option, "-location"))  
         {
@@ -776,6 +764,31 @@ retry:
                 goto retry;
         }
 
+
+        if(!stricmp(option, "-trunking"))
+        {
+                ++argv;
+                if(!*argv)
+                {
+                        cerr << "bayonne: -trunking: missing argument" << endl;
+                        exit(-1);
+                }
+                keyengine.setValue("trunking", *(argv++));
+                goto retry;
+        }
+            
+        if(!stricmp(option, "-protocol"))
+        {
+                ++argv;
+                if(!*argv)
+                {
+                        cerr << "bayonne: -protocol: missing argument" << endl;
+                        exit(-1);
+                }
+                keyengine.setValue("protocol", *(argv++));
+                goto retry;
+        } 
+
         if(!stricmp(option, "-bind"))
         {
                 ++argv;    
@@ -801,6 +814,7 @@ retry:
 		++argv;
                 goto retry;
 	}
+#endif
 
 	if(**argv == '-')
 	{
@@ -816,7 +830,7 @@ skip:
 			keyoptions.setValue("modules", *argv);
 		else if(!stricmp(ext, ".conf") || !stricmp(ext, ".ini"))
 			slog.error("bayonne: %s: invalid script file", *argv);
-		else if(!stricmp(ext, ".mac") || !stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext) || !stricmp(ext, ".def"))
+		else if(!stricmp(ext, ".mac") || !stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext))
 		{
 			prefix = strrchr(*argv, '/');
 			if(!prefix)
@@ -844,10 +858,7 @@ skip:
 				else
 					script = NULL;
 
-				if(!stricmp(ext, ".def"))
-					runtime.setValue("definitions", prefix);
-				else
-					runtime.setValue(*argv, prefix);
+				runtime.setValue(prefix, *argv);
 			}
 		}
 		else
