@@ -19,6 +19,30 @@
 #include <cstdarg>
 #include "server.h"
 
+#if defined(_MSC_VER) && _MSC_VER >= 1300
+#if defined(_WIN64_) || defined(__WIN64__)     
+#define RLL_SUFFIX "x64"
+#elif defined(_M_IX86)
+#define RLL_SUFFIX "x86"
+#else
+#define RLL_SUFFIX "xlo"
+#endif
+#endif 
+
+#if defined(__MINGW32__) | defined(__CYGWIN32__)
+#define RLL_SUFFIX "dso"
+#endif
+
+#ifdef  W32
+#ifndef RLL_SUFFIX
+#define RLL_SUFFIX "rll"
+#endif
+#endif 
+
+#ifndef RLL_SUFFIX
+#define RLL_SUFFIX "dso"
+#endif 
+
 namespace server {
 using namespace ost;
 using namespace std;
@@ -27,6 +51,8 @@ Runtime::Runtime() :
 ScriptRuntime()
 {
 	static ScriptInterp::Define interp[] = {
+		{"bgm", false, (Method)&Methods::scrBGM,
+			(Check)&Checks::chkBGM},
 		{"config", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkConfig},
 		{"dialtone", false, (Method)&Methods::scrTone,
@@ -93,13 +119,6 @@ ScriptRuntime()
 			(Check)&Checks::chkSleep},
 		{"route", false, (Method)&Methods::scrRoute,
 			(Check)&Checks::chkRoute},
-#ifdef  WIN32
-                {"link", false, (Method)&Methods::scrCopy,
-                        (Check)&Checks::chkMove},
-#else
-                {"link", false, (Method)&Methods::scrLink,
-                        (Check)&Checks::chkMove},
-#endif
 		{"copy", false, (Method)&Methods::scrCopy,
 			(Check)&Checks::chkMove},
 		{"move", false, (Method)&Methods::scrMove,
@@ -132,6 +151,10 @@ ScriptRuntime()
 			(Check)&Checks::chkPathname},
 		{"play", false, (Method)&Methods::scrPlay,
 			(Check)&Checks::chkPathname},
+		{"xmlbind", false, (Method)&Methods::scrBind,
+			(Check)&Checks::chkBind},
+                {"xml", false, (Method)&Methods::scrBind,
+                        (Check)&Checks::chkBind}, 
         	{NULL, false, NULL, NULL}};
 
         trap("timeout", false);
@@ -300,9 +323,9 @@ bool Runtime::isInput(Line *line)
 	if(line->scr.method == (Method)&Methods::scrInput)
 		return true;
 
-	if(line->scr.method == (Method)&Methods::scrRead)
-		return true;
-
+        if(line->scr.method == (Method)&Methods::scrRead)  
+                return true;
+                               
 	if(line->scr.method == (Method)&Methods::scrCleardigits)
 		return true;
 
@@ -312,6 +335,19 @@ bool Runtime::isInput(Line *line)
 	return false;
 }
 
+bool Runtime::testBinding(ScriptInterp *interp, const char *v)
+{
+	const char *cp = keyserver.getLast("binding");
+
+	if(!v || !cp)
+		return false;
+
+	if(!stricmp(cp, v))
+		return true;
+
+	return false;
+}
+
 bool Runtime::testDriver(ScriptInterp *interp, const char *v)
 {
 	if(BayonneDriver::get(v))
@@ -643,7 +679,6 @@ bool Runtime::command(char *cmd)
 	bool rtn;
 	BayonneDriver *d;
 	const char *dial, *caller, *display;
-	char buf[65];
 
 	cmd = strtok_r(cmd, " \t\r\n", &tok);
 	if(!cmd || ispunct(*cmd) || !*cmd)
@@ -677,17 +712,6 @@ bool Runtime::command(char *cmd)
 		return true;
 	}
 		
-        if(!stricmp(cmd, "define"))
-        {
-                cmd = strtok_r(NULL, " \t\r\n", &tok);
-                if(!cmd)
-                        return false;
-
-                snprintf(buf, sizeof(buf), "%s.def", cmd);
-                Bayonne::server->setValue("definitions", buf);
-                return true;
-        }
-
 	if(!stricmp(cmd, "load"))
 	{
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
@@ -804,8 +828,8 @@ void Runtime::process(void)
 	snprintf(buf, sizeof(buf), "%s/%s.ctrl", keypaths.getLast("runfiles"), argv0);
 	remove(buf);
 	mkfifo(buf, 0770);
-	fifo = ::open(buf, O_RDWR);
 	keypaths.setValue("runfifo", buf);
+	fifo = ::open(buf, O_RDWR);
 	for(;;)
 	{
 		readline(buf, sizeof(buf));
@@ -852,7 +876,7 @@ bool Runtime::loadBinder(const char *path)
 #endif
 #endif   
         if(!prefix)
-	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binders";
+   	 		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binders";
 #else
 
 #ifdef  HAVE_TESTING
@@ -873,7 +897,7 @@ bool Runtime::loadBinder(const char *path)
 #endif 
 
 #ifdef  WIN32
-        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.%s" prefix, path, RLL_SUFFIX);
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.%s", prefix, path, RLL_SUFFIX);
 #else
         snprintf(pathbuf, sizeof(pathbuf), "%s/%s.bin", prefix, path);
 #endif  
@@ -892,7 +916,7 @@ bool Runtime::loadBinder(const char *path)
 
         if(!canAccess(path))
         {
-                Bayonne::errlog("access", "cannot load  %s", path);
+                Bayonne::errlog("access", "cannot load binder %s", path);
                 return false;
         }  
 
