@@ -99,40 +99,21 @@ static void version(void)
         exit(0);
 }
 
-static void plugins(void)
-{
-	char *tok, *cp, *sp = (char *)keyserver.getLast("plugins");
-	if(sp && !strnicmp(sp, "no", 2))
-		sp = NULL;
-		
-	if(sp && !*sp)
-		sp = NULL;
-		
-	if(sp)
-		cp = strtok_r(sp, " ,;\t", &tok);
-	else
-		cp = NULL;
-
-	while(cp)
-	{
-		Bayonne::loadPlugin(cp);
-		cp = strtok_r(NULL, " ,;:\t", &tok);
-	}	
-}	
-
 static void loading(void)
 {
 	char buffer[256];
 	char lang[32];
 	char ** keys;
 	char *plist[65];
-	const char *cp, *proto;
+	const char *cp, *proto = NULL;
 	char *sp, *tok;
 	unsigned count = keyoptions.getCount("modules");
+	unsigned pcount;
 	BayonneDriver *driver;
 	BayonneTranslator *translator = NULL;
 	static char vlib[64];
 	bool pflag = true;
+	bool loaded = false;
 #ifdef	HAVE_LIBEXEC
 	size_t bs = 0;
 	int pri = 0;
@@ -166,8 +147,6 @@ static void loading(void)
 
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
 		keypaths.getLast("modexec"));
-
-	runtime.setValue("definitions", "libexec.mac");
 #endif
         cp = keyserver.getLast("language");
         if(cp && (strlen(cp) == 2 || cp[2] == '_'))  
@@ -216,24 +195,72 @@ static void loading(void)
 
 	driver = NULL;	
 	cp = keyengine.getLast("driver");
-#ifndef	WIN32
-	if(cp && !stricmp(cp, "autodetect"))
-	{
-		cp = Process::getEnv("DRIVER_AUTODETECT");
-		if(!cp || !*cp)
-			cp = "default";
-	}
-	if(cp && !stricmp(cp, "default"))
-	{
-		cp = Process::getEnv("DRIVER");
-		if(!cp || !*cp)
-			cp = "soundcard";
-	}
-#endif
 	if(cp && *cp)
+	{
 		driver = BayonneDriver::loadDriver(cp);
+		if(driver)
+			loaded = true;
+	}
+	else
+	{
+		driver = NULL;
+		cp = keyengine.getLast("trunking");
+		if(cp && *cp && strnicmp(cp, "no", 2))
+			driver = BayonneDriver::loadTrunking(cp);
+		if(driver)
+			loaded = true;
+		
+		cp = keyengine.getLast("protocol");
+		if(cp && *cp && strnicmp(cp, "no", 2))
+		{
+			pflag = true;
+			proto = cp;
+			if(!stricmp(cp, "yes") || !stricmp(cp, "any"))
+				proto = NULL;
+			if(!stricmp(cp, "all") || !stricmp(cp, "use"))
+				proto = NULL;
+		}
+		else
+		{
+			proto = NULL;
+			pflag = false;
+		}
 
-	if(!driver)
+		// see if trunking driver disables protocols...
+		
+		if(pflag && driver)
+			pflag = BayonneDriver::useProtocols();
+
+		if(!pflag)
+			goto check;
+
+		// load protocols....
+
+		pcount = keyprotocols.getIndex(plist, sizeof(plist) / sizeof(char *));
+		keys = plist;
+		while(plist && *keys && pflag)
+		{
+			cp = NULL;
+			if(proto && stricmp(*keys, proto))
+				cp = keyprotocols.getLast(*keys);
+
+			if(cp && *cp)
+				driver = BayonneDriver::loadProtocol(*keys, atoi(cp));
+			if(driver)
+				loaded = true;
+
+			++keys;
+		}
+
+		if(proto)
+			driver = BayonneDriver::loadProtocol(cp, 0);
+		if(driver)
+			loaded = true;
+	}		
+
+check:
+
+	if(!loaded)
 	{
 		slog.critical("no driver loaded; enable in server.conf...");
 		stop(-1);
@@ -283,20 +310,7 @@ start:
 	BayonneSysexec::startup();
 #endif
 // reload
-	cp = keyserver.getLast("binding");
-#ifdef	WIN32
-	if(cp && !stricmp(cp, "default"))
-		cp = "ivrscript1";
-#else
-	if(cp && !stricmp(cp, "default"))
-	{
-		cp = Process::getEnv("BINDING");
-		if(!cp || !*cp)
-			cp = "ivrscript1";
-	}
-#endif
-	plugins();
-	runtime.loadBinder(cp);
+	runtime.loadBinder(keyserver.getLast("binding"));
 	Bayonne::reload();
 	if(!Bayonne::compile_count)
 	{
@@ -336,16 +350,11 @@ static void logging(void)
 
 static void checking(void)
 {
-	const char *cp = keyserver.getLast("binding");
-
 	keyserver.setValue("logging", "debug");
 	logging();
 	if(!Bayonne::getTimeslotCount())
 		Bayonne::allocate(1, dynamic_cast<ScriptCommand *>(&runtime));
-	if(cp && !stricmp(cp, "default"))
-		cp = "ivrscript1";
-	plugins();
-	runtime.loadBinder(cp);
+	runtime.loadBinder(keyserver.getLast("binding"));
 	Bayonne::reload();
         if(!Bayonne::compile_count)
         {
@@ -441,10 +450,6 @@ int main(int argc, char **argv)
 
 	keyserver.setValue("argv0", argv0);
 
-#ifdef	HAVE_LIBEXEC
-	runtime.setValue("definitions", "libexec.def");
-#endif
-
 	if(argc == 2)
 	{
 		cp = argv[1];
@@ -487,8 +492,6 @@ int main(int argc, char **argv)
                 	// and dump them without further processing.
                 	cout << "[paths]" << endl;   
                 	dumpConfig(keypaths);
-			cout << "[switch]" << endl;
-			dumpConfig(keyswitch);
                 	cout << "[server]" << endl;
                 	dumpConfig(keyserver);
                 	cout << "[engine]" << endl;
@@ -537,17 +540,6 @@ int main(int argc, char **argv)
                         stop(-1);
                 }
         }
-	else
-		Process::setGroup(keyserver.getLast("group"));
-	cp = keyengine.getLast("driver");
-	if(cp && !stricmp(cp, "autodetect"))
-	{
-		cp = Process::getEnv("DRIVER_AUTODETECT");
-		if(!cp || !*cp)
-			cp = Process::getEnv("DRIVER");
-		if(!cp || !*cp)
-			Bayonne::provision_daemon = false;
-	}
 	if(Bayonne::provision_daemon)
 		Process::detach();
 
